@@ -1,7 +1,7 @@
 from ..util import util, dag, validator,list2table,formater
 import json
 
-from terminal import bold, magenta, gray, blue, green, red, yellow, confirm
+from terminal import bold, magenta, white, blue, green, red, yellow, confirm
 
 def status(task=None,dag_only=False, validate=True):
     task_name = task
@@ -97,9 +97,9 @@ def print_task_desc(task_name, taskDesc):
             print('    %s: %s' % (bold(k),v))
 
 
-    print('%s: %s' % ( blue('InputMappingConfig:'),formater.to_dict( taskDesc['Parameters']['InputMappingConfig']) ))
-    print('%s: %s' % ( blue('StdoutRedirectPath:'), taskDesc['Parameters']['StdoutRedirectPath'] ))
-    print('%s: %s' % ( blue('StderrRedirectPath:'), taskDesc['Parameters']['StderrRedirectPath'] ))
+    print('%s: %s' % ( blue('InputMappingConfig:'),formater.to_dict( taskDesc['Parameters'].get('InputMappingConfig')) ))
+    print('%s: %s' % ( blue('StdoutRedirectPath:'), taskDesc['Parameters'].get('StdoutRedirectPath') ))
+    print('%s: %s' % ( blue('StderrRedirectPath:'), taskDesc['Parameters'].get('StderrRedirectPath') ))
 
 
     if taskDesc.get('InputMapping'):
