@@ -4,15 +4,15 @@ from .externals.command import Command
 from . import const,i18n_util,cli_project,cli_oss
 from .action import login, config, info, cluster, job, cluster_create, cluster_delete, cluster_update, instance_type \
     , job_delete, job_restart, job_stop, job_update, job_create, log_fetch, job_submit,checker\
-    ,image,image_create,image_delete
+    ,image,image_create,image_delete,disk_type
 
 import os
 
 COMMAND = const.COMMAND
 CMD = const.CMD
 
-IMG_ID = const.IMG_ID
-INS_TYPE = const.INS_TYPE
+IMG_ID = 'img-xxxxxx'
+INS_TYPE = 'ecs.s3.large'
 
 VERSION = const.VERSION
 
@@ -65,6 +65,7 @@ class Cli:
         cmd_config.option('-l,--locale [locale]', MSG['config']['option']['locale'])
         cmd_config.option('-i,--image [imageId]', MSG['config']['option']['image'])
         cmd_config.option('-t,--type [instanceType]', MSG['config']['option']['type'])
+        cmd_config.option('-s,--ssl [ssl]', MSG['config']['option']['ssl'], visible=IS_GOD)
         cmd_config.option('-v,--version [version]', MSG['config']['option']['version'], visible=IS_GOD)
         cmd_config.option('-g,--god [god]', MSG['config']['option']['god'], visible=IS_GOD)
         self.program.action(cmd_config)
@@ -93,6 +94,18 @@ class Cli:
         self.program.action(cmd_instance_type)
 
 
+        # disk type
+        cmd_disk_type = Command('disk_type', alias=['d'],
+                                    description=MSG['disk_type']['description'],
+                                    usage='''Usage: %s disk_type|d [option]
+
+        Examples:
+
+            1. %s d ''' % (COMMAND, CMD),
+                                    func=disk_type.list)
+        self.program.action(cmd_disk_type)
+
+
 
 
 
@@ -222,6 +235,8 @@ class Cli:
                                   resolve=image_create.trans_platform)
         cmd_create_image.option("-d, --description [description]",
                                   MSG['create_image']['option']['description'])
+        cmd_create_image.option("--show_json",
+                                  MSG['create_image']['option']['show_json'], visible=IS_GOD)
         self.program.action(cmd_create_image)
 
 
@@ -260,15 +275,14 @@ class Cli:
                                      func=cluster_create.create_cluster)
         cmd_create_cluster.option("-i, --image [imageId]", MSG['create_cluster']['option']['image'],
                                   resolve=cluster_create.trans_image)
-        cmd_create_cluster.option("-t, --type [instanceType]", MSG['create_cluster']['option']['type'],
-                                  resolve=cluster_create.trans_type)
+        cmd_create_cluster.option("-t, --type [instanceType]", MSG['create_cluster']['option']['type'])
         cmd_create_cluster.option("-n, --nodes [instanceCount]", MSG['create_cluster']['option']['nodes'],
                                   resolve=cluster_create.trans_nodes)
         cmd_create_cluster.option("-d, --description [description]",
                                   MSG['create_cluster']['option']['description'])
-        cmd_create_cluster.option("-u, --userData [key1:value1,key2:value1...]",
-                                  MSG['create_cluster']['option']['userData'],
-                                  resolve=cluster_create.trans_userData)
+        cmd_create_cluster.option("-u, --user_data [kv_pairs]",
+                                  MSG['create_cluster']['option']['user_data'],
+                                  resolve=cluster_create.trans_user_data)
         cmd_create_cluster.option("--disk [disk_configs]",
                                   MSG['create_cluster']['option']['disk'],
                                   resolve=cluster_create.trans_disk)
@@ -452,9 +466,12 @@ class Cli:
         cmd_submit_job.option("-w, --write_mount [kv_pairs]", MSG['submit']['option']['write_mount'])
         cmd_submit_job.option("-m, --mount [kv_pairs]", MSG['submit']['option']['mount'])
         cmd_submit_job.option("--docker [docker]",  MSG['submit']['option']['docker'])
+        cmd_submit_job.option("-u,--user_data [kv_pairs]", MSG['submit']['option']['user_data'])
         cmd_submit_job.option("--disk [disk_configs]",
                                   MSG['submit']['option']['disk'],
                                   resolve=job_submit.trans_disk)
+        cmd_submit_job.option("--lock", MSG['submit']['option']['lock'])
+        cmd_submit_job.option("--locale [locale]", MSG['submit']['option']['locale'])
         cmd_submit_job.option("--file [file]",  MSG['submit']['option']['file'])
         cmd_submit_job.option("--show_json",
                               MSG['submit']['option']['show_json'], visible=IS_GOD)
