@@ -1,7 +1,10 @@
 # -*- coding: utf-8 -*-
-from ..const import *
 from ..util import smart_unicode
 from ..const import STRING
+from ..const import CMD
+
+IMG_ID = 'img-ubuntu'
+INS_TYPE = 'ecs.s3.large'
 
 def getJSON():
     o = __get_json()
@@ -31,10 +34,11 @@ def __get_json():
                 "region": '设置区域, 如:cn-qingdao',
                 "osspath": '设置默认OSS路径',
                 "locale": '设置语言地域, 可选范围:[zh_CN|en]',
-                "image": '设置默认镜像Id',
-                "type": "设置默认InstanceType, 运行 '%s it' 可以看到本区域支持的instanceType" % (CMD),
+                "image": "设置默认镜像Id, 运行 '%s i' 可以列出可用的Image" % CMD,
+                "type": "设置默认InstanceType, 运行 '%s t' 可以看到本区域支持的instanceType" % (CMD),
                 'version': "设置版本, 支持预发环境使用,版本如: 2015-10-01",
-                'god': "使用上帝模式"
+                'god': "使用上帝模式, 可选范围:[true|false]",
+                'ssl': '使用https访问BatchCompute, 可选范围:[true|false]'
             }
         },
         'info': {
@@ -44,6 +48,12 @@ def __get_json():
             "has_upgrade": "你可以执行 'pip install -U batchcompute-cli' 来升级",
             "has_upgrade2": "如果提示没有权限, 请使用 'sudo pip install -U batchcompute-cli'"
         },
+        "image": {
+            "description": '显示可用镜像列表.'
+        },
+        "disk_type": {
+            "description": '显示可用磁盘类型列表.'
+        },
         "instance_type": {
             "description": '显示资源类型列表.'
         },
@@ -72,21 +82,38 @@ def __get_json():
                 'stdout': '只显示stdout日志'
             }
         },
+        'create_image': {
+            'description': '注册镜像',
+            'option': {
+                'platform': "可选, 平台范围[Linux|Windows] 默认: Linux",
+                'description': "可选, 描述信息, string",
+                'show_json': '只显示 image json不创建'
+            }
+        },
+        'delete_image': {
+            'description': '注销镜像, 支持批量删除',
+            'option': {
+                'yes': "可选, 不要询问直接注销"
+            }
+        },
         'create_cluster': {
             'description': '创建集群',
             'option': {
-                'image': "可选, imageId, 默认: %s" % IMG_ID,
-                'type': "可选, instanceType, 更多信息输入 %s it 查看, 默认: %s" % (CMD, INS_TYPE),
+                'image': "可选, imageId, 更多信息输入 %s i 查看" % CMD,
+                'type': "可选, instanceType, 更多信息输入 %s t 查看" % (CMD),
                 'nodes': "可选, int类型, default: 1",
                 'description': "可选, 描述信息, string",
-                'userData': "可选, 用户数据, k:v 对,多个逗号隔开, 格式: k:v,k2:v2",
+                'user_data': "可选, 用户数据, k:v 对,多个逗号隔开, 格式: k:v,k2:v2",
                 'disk': """可选, 挂载磁盘, 支持系统盘配置和一块数据盘(可选)的配置,
-
-        使用方法如: "--disk system:ephemeral:40,data:cloud:50:/home/disk1".
-        默认只挂载一个系统盘:类型为ephemeral,大小40GB.
-        系统盘配置格式: system:<cloud|ephemeral>:<40-500>, 举例: system:cloud:40, 表示系统盘挂载40GB的云盘.
-        数据盘配置格式: data:<cloud|ephemeral>:<5-2000>:<mount-point>, 举例: data:cloud:5:/home/disk1, 表示挂载一个5GB的云盘作为数据盘, window下只能挂载到驱动,如E盘:"data:cloud:5:E".
-        (注意: 数据盘使用ephemeral的时候,size取值范围限制为:[5-1024]GB).""",
+                                      使用方法如: "--disk system:ephemeral:40,data:cloud:50:/home/disk1".
+                                      默认只挂载一个系统盘:类型为ephemeral,大小40GB.
+                                      系统盘配置格式: system:<cloud|ephemeral>:<40-500>,
+                                      举例: system:cloud:40, 表示系统盘挂载40GB的云盘.
+                                      数据盘配置格式: data:<cloud|ephemeral>:<5-2000>:<mount-point>,
+                                      举例: data:cloud:5:/home/disk1, 表示挂载一个5GB的云盘作为数据盘, window下只能挂载到驱动,如E盘:"data:cloud:5:E".
+                                      (注意: 数据盘使用ephemeral的时候,size取值范围限制为:[5-1024]GB).
+                                      (运行 '%s d' 可以看到本区域支持的diskType).
+                 """ % CMD,
                 'show_json': '只显示cluster json不创建'
             }
         },
@@ -141,9 +168,9 @@ def __get_json():
                                       默认是一个AutoCluster配置字符串: img=%s:type=%s.
                                       你可以使用一个已经存在的集群ID(type '%s c' for more cluster id),
                                       或者可以使用AutoCluster配置字符串, 格式: img=<imageId>:type=<instanceType>
-                                      (imageId可以查看官网帮助文档)
-                                      (运行 '%s it' 可以看到本区域支持的instanceType). """ % (
-                IMG_ID, INS_TYPE, CMD, CMD),
+                                      (运行 '%s i' 可以列出可用的Image, 其他的可用查看官网文档)
+                                      (运行 '%s t' 可以看到本区域支持的instanceType). """ % (
+                IMG_ID, INS_TYPE, CMD, CMD, CMD),
                 'pack': "可选,打包指定目录下的文件,并上传到OSS, 如果没有指定这个选项则不打包不上传",
                 'priority': '可选,int类型,指定作业优先级,默认:0\n',
                 'timeout': "可选,超时时间(如果实例运行时间超时则失败), 默认: 172800(单位秒,表示2天)",
@@ -162,14 +189,20 @@ def __get_json():
                                       如: localhost:5000/myubuntu@oss://bucket/dockers/
                                       或者: myubuntu@oss://bucket/dockers/""",
                 'file': """可选,使用配置文件提交作业,如果你显示指定其他选项,配置文件中的选项会被覆盖""",
+                'user_data': "可选, 用户数据, k:v 对,多个逗号隔开, 格式: k:v,k2:v2",
                 'disk': """可选,挂载磁盘, 只在使用AutoCluster时有效, 支持系统盘配置和一块数据盘(可选)的配置,
 
-                使用方法如: "--disk system:ephemeral:40,data:cloud:50:/home/disk1".
-                默认只挂载一个系统盘:类型为ephemeral,大小40GB.
-                系统盘配置格式: system:<cloud|ephemeral>:<40-500>, 举例: system:cloud:40, 表示系统盘挂载40GB的云盘.
-                数据盘配置格式: data:<cloud|ephemeral>:<5-2000>:<mount-point>, 举例: data:cloud:5:/home/disk1, 表示挂载一个5GB的云盘作为数据盘, window下只能挂载到驱动,如E盘:"data:cloud:5:E".
-                (注意: 数据盘使用ephemeral的时候,size取值范围限制为:[5-1024]GB).
-                        """,
+                                      使用方法如: "--disk system:ephemeral:40,data:cloud:50:/home/disk1".
+                                      默认只挂载一个系统盘:类型为ephemeral,大小40GB.
+                                      系统盘配置格式: system:<cloud|ephemeral>:<40-500>,
+                                      举例: system:cloud:40, 表示系统盘挂载40GB的云盘.
+                                      数据盘配置格式: data:<cloud|ephemeral>:<5-2000>:<mount-point>,
+                                      举例: data:cloud:5:/home/disk1, 表示挂载一个5GB的云盘作为数据盘, window下只能挂载到驱动,如E盘:"data:cloud:5:E".
+                                      (注意: 数据盘使用ephemeral的时候,size取值范围限制为:[5-1024]GB).
+                                      (运行 '%s d' 可以看到本区域支持的diskType).
+                        """ % CMD,
+                'lock': """OSS挂载是否支持网络文件锁。""",
+                'locale': """OSS Object挂载到本地时使用的字符集。可选范围包括GBK、GB2312-80、BIG5、UTF-8、ANSI、EUC-JP、EUC-TW、EUC-KR、SHIFT-JIS、KSC5601等。""",
                 'show_json': '只显示json不提交作业'
 
             }
@@ -197,8 +230,9 @@ def __get_json():
                               默认是一个AutoCluster配置字符串: img=%s:type=%s.
                               你可以使用一个已经存在的集群ID(type '%s c' for more cluster id),
                               或者可以使用AutoCluster配置字符串, 格式: img=<imageId>:type=<instanceType>
-                              (运行 '%s it' 可以看到本区域支持的instanceType). """
-                               % (IMG_ID, INS_TYPE, CMD, CMD),
+                              (运行 '%s i' 可以列出可用的Image, 其他的可用查看官网文档)
+                              (运行 '%s t' 可以看到本区域支持的instanceType). """
+                               % (IMG_ID, INS_TYPE, CMD, CMD, CMD),
                     "docker": """可选,使用docker镜像运行, 格式如:<oss_docker_storage_path>:<docker_name>"""
                 }
             },
@@ -216,8 +250,9 @@ def __get_json():
                                   默认是一个AutoCluster配置字符串: img=%s:type=%s.
                                   你可以使用一个已经存在的集群ID(type '%s c' for more cluster id),
                                   或者可以使用AutoCluster配置字符串, 格式: img=<imageId>:type=<instanceType>
-                                  (运行 '%s it' 可以看到本区域支持的instanceType). """
-                               % (IMG_ID, INS_TYPE, CMD, CMD),
+                                  (运行 '%s i' 可以列出可用的Image, 其他的可用查看官网文档)
+                                  (运行 '%s t' 可以看到本区域支持的instanceType). """
+                               % (IMG_ID, INS_TYPE, CMD, CMD, CMD),
 
                     'docker': 'Docker镜像名, 需要以前缀"localhost:5000/"打tag'
                 }
