@@ -2,9 +2,9 @@
 # -*- coding: UTF-8 -*-
 import json
 import os
-from ..util import client,it,result_cache
+from ..util import client,it,result_cache, config
 from terminal import yellow,blue
-from ..const import *
+from ..const import CMD
 import re
 
 
@@ -56,8 +56,8 @@ def parse_cluster_cfg(s=None):
     if not s:
         return {
             'AutoCluster':{
-                'ECSImageId': IMG_ID,
-                'InstanceType': INS_TYPE
+                'ImageId': config.get_default_image(),
+                'InstanceType': config.get_default_instance_type()
             },
             'ClusterId': ''
         }
@@ -82,13 +82,13 @@ def parse_cluster_cfg(s=None):
 
 
         if not m.get('ImageId') and not m.get('ECSImageId'):
-            m['ECSImageId']= IMG_ID
+            m['ImageId']= config.get_default_image()
 
         if not m.get('InstanceType'):
-            m['InstanceType']= INS_TYPE
+            m['InstanceType']= config.get_default_instance_type()
 
-        if not it.get_ins_type_map().get(m['InstanceType']):
-            print(yellow("Warning: '%s' may not be valid, type '%s it' for more" % (m['InstanceType'], CMD)))
+        # if not it.get_ins_type_map().get(m['InstanceType']):
+        #     print(yellow("Warning: '%s' may not be valid, type '%s it' for more" % (m['InstanceType'], CMD)))
 
         #print(white('using AuthCluster: %s' % m))
         return {'AutoCluster':m,'ClusterId':''}
